@@ -267,8 +267,8 @@ exchange_mapi_util_free_attachment_list (GSList **attach_list)
 		g_free (attachment);
 		attachment = NULL;
 	}
-	g_slist_free (l);
-	l = NULL;
+	g_slist_free (*attach_list);
+	*attach_list = NULL;
 }
 
 void 
@@ -287,12 +287,12 @@ exchange_mapi_util_free_recipient_list (GSList **recip_list)
 			g_free (recipient->in.ext_lpProps);
 		if (recipient->in.req_cValues)
 			g_free (recipient->in.req_lpProps);
-/*		if (recipient->out_SRow.cValues)
-			g_free (recipient->out_SRow.lpProps);
+/*		if (recipient->out.all_cValues)
+			g_free (recipient->out.all_lpProps);
 */		g_free (recipient);
 	}
-	g_slist_free (l);
-	l = NULL;
+	g_slist_free (*recip_list);
+	*recip_list = NULL;
 }
 
 void 
@@ -310,8 +310,8 @@ exchange_mapi_util_free_stream_list (GSList **stream_list)
 		g_free (stream);
 		stream = NULL;
 	}
-	g_slist_free (l);
-	l = NULL;
+	g_slist_free (*stream_list);
+	*stream_list = NULL;
 }
 
 
@@ -593,20 +593,3 @@ exchange_crlf_to_lf (const char *in)
 	return out;
 }
 
-/**
- * exchange_mapi_util_profile_name:
- * @username: User name of the profile
- * @domain: Domain name of the profile
- *
- * Constructs profile name from given @username and @domain and
- * returns it as a newly allocated string.
- **/
-gchar *
-exchange_mapi_util_profile_name (const gchar *username, const gchar *domain)
-{
-	gchar *res;
-
-	res = g_strdup_printf ("%s@%s", username, domain);
-
-	return g_strcanon (res, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789@", '_');
-}
